﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using HLWebOKBQueryPlugin.Models;
using HLWebOKBQueryPlugin.Helpers;
using HLWebOKBQueryPlugin.OKBQueryService;
using System.Web.UI.DataVisualization.Charting;
using System.Drawing;
using System.IO;

namespace HLWebOKBQueryPlugin.Controllers {
  public class ChartController : Controller {
    //
    // GET: /Chart/


    public ActionResult UpdateBubbleChart(FormCollection collection) {


      String selectedAxisX = collection.Get("valuesAxisXCombobox");
      String selectedAxisY = collection.Get("valuesAxisYCombobox");
      String selectedBubbleSize = collection.Get("bubbleSizeCombobox");

      Response.Write("axis x => " + selectedAxisX);
      Response.Write("axis y => " + selectedAxisY);
      Response.Write("size => " + selectedBubbleSize);

      ChartModel cm = new ChartModel();

      // Later, we will get the runs from the session ...
      QueryServiceClient client = Query.GetClientFactory("okbtester", "okbtester");

      long[] runIds = new long[5];
      for (int i = 0; i < 5; i++) {
        runIds[i] = i;
      }
      Run[] runs = client.GetRuns(runIds, false);

      cm.UpdateRunCollection(runs);
      cm.UpdateBubbleChart(selectedAxisY, selectedAxisX, selectedBubbleSize);

      return View("Index",cm);
    }



    public FileResult CreateBubbleChart(ChartModel model)
    {
        IList<int> items = new List<int>();

        items.Add(1);
        items.Add(2);
        items.Add(5);
        items.Add(10);

        Chart chart = new Chart();
        chart.Width = 700;
        chart.Height = 300;
        chart.BackColor = Color.FromArgb(211, 223, 240);
        chart.BorderlineDashStyle = ChartDashStyle.Solid;
        chart.BackSecondaryColor = Color.White;
        chart.BackGradientStyle = GradientStyle.TopBottom;
        chart.BorderlineWidth = 1;
        chart.Palette = ChartColorPalette.BrightPastel;
        chart.BorderlineColor = Color.FromArgb(26, 59, 105);
        chart.RenderType = RenderType.BinaryStreaming;
        chart.BorderSkin.SkinStyle = BorderSkinStyle.Emboss;
        chart.AntiAliasing = AntiAliasingStyles.All;
        chart.TextAntiAliasingQuality = TextAntiAliasingQuality.Normal;
        chart.Titles.Add("Bubble Chart");
        //chart.Legends.Add(CreateLegend());
        chart.Series.Add(CreateSeries(items,SeriesChartType.Bubble));
        chart.ChartAreas.Add(CreateChartArea());



        MemoryStream ms = new MemoryStream();
        chart.SaveImage(ms);
        return File(ms.GetBuffer(), @"image/png");
    }



    public Series CreateSeries(IList<int> results, SeriesChartType chartType)
    {
        Series seriesDetail = new Series();
        seriesDetail.Name = "Result Chart";
        seriesDetail.IsValueShownAsLabel = false;
        seriesDetail.Color = Color.FromArgb(198, 99, 99);
        seriesDetail.ChartType = chartType;
        seriesDetail.BorderWidth = 2;
        DataPoint point;

        foreach (int result in results)
        {
            point = new DataPoint();
            point.AxisLabel = result.ToString();
            point.YValues = new double[] { (double)result };
            seriesDetail.Points.Add(point);
        }
        seriesDetail.ChartArea = "Result Chart";
        return seriesDetail;
    }



    public ChartArea CreateChartArea()
    {
        ChartArea chartArea = new ChartArea();
        chartArea.Name = "Result Chart";
        chartArea.BackColor = Color.Transparent;
        chartArea.AxisX.IsLabelAutoFit = false;
        chartArea.AxisY.IsLabelAutoFit = false;
        chartArea.AxisX.LabelStyle.Font =
           new Font("Verdana,Arial,Helvetica,sans-serif",
                    8F, FontStyle.Regular);
        chartArea.AxisY.LabelStyle.Font =
           new Font("Verdana,Arial,Helvetica,sans-serif",
                    8F, FontStyle.Regular);
        chartArea.AxisY.LineColor = Color.FromArgb(64, 64, 64, 64);
        chartArea.AxisX.LineColor = Color.FromArgb(64, 64, 64, 64);
        chartArea.AxisY.MajorGrid.LineColor = Color.FromArgb(64, 64, 64, 64);
        chartArea.AxisX.MajorGrid.LineColor = Color.FromArgb(64, 64, 64, 64);
        chartArea.AxisX.Interval = 1;

        return chartArea;
    }




    public ActionResult Index() {
      ChartModel cm = new ChartModel();

      // Later, we will get the runs from the session ...
      QueryServiceClient client = Query.GetClientFactory("okbtester", "okbtester");

      long[] runIds = new long[5];
      for (int i = 0; i < 5; i++) {
        runIds[i] = i;
      }
      Run[] runs = client.GetRuns(runIds, false);

      cm.UpdateRunCollection(runs);


      return View(cm);
    }

    // [ChildActionOnly]
    public ActionResult BubbleChart() {
      ChartModel cm = new ChartModel();

      return PartialView("BubbleChart", cm); // name of usercontrol
    }


    //public ActionResult BoxPlot()
    //{
    //    return View();
    //}

  }
}
